<!DOCTYPE html>
<html>
    <!-- 
    noVNC example: simple example using default UI
    Copyright (C) 2012 Joel Martin
    noVNC is licensed under the MPL 2.0 (see LICENSE.txt)
    This file is licensed under the 2-Clause BSD license (see LICENSE.txt).

    Connect parameters are provided in query string:
        http://example.com/?host=HOST&port=PORT&encrypt=1&true_color=1
    -->
    <head>
        <title>noVNC</title>
        <meta http-equiv="X-UA-Compatible" content="chrome=1">
        <link rel="stylesheet" href="include/base.css" title="plain">
        <!--
        <script type='text/javascript' 
            src='http://getfirebug.com/releases/lite/1.2/firebug-lite-compressed.js'></script>
        -->
        <script src="include/util.js"></script>
    </head>

    <body style="margin: 0px;">
        <div id="noVNC_screen">
            <div id="noVNC_status_bar" class="noVNC_status_bar" style="margin-top: 0px;">
                <table border=0 width="100%"><tr>
                    <td><div id="noVNC_status">Loading</div></td>
                    <td width="1%"><div id="noVNC_buttons">
                        <input type=button value="Disconnect"
                            id="disconnectButton">
                        <input type=button value="Send CtrlAltDel"
                            id="sendCtrlAltDelButton">
                            </div></td>
                </tr></table>
            </div>
            <h2 id="noVNC_NOlogo">Ovm Console</h2>
            <canvas id="noVNC_canvas" width="640px" height="20px">
                Canvas not supported.
            </canvas>
        </div>

        <script>
        /*jslint white: false */
        /*global window, $, Util, RFB, */
        "use strict";

        // Load supporting scripts
        Util.load_scripts(["webutil.js", "base64.js", "websock.js", "des.js",
                           "input.js", "display.js", "jsunzip.js", "rfb.js", "logo.js"]);

        var rfb;

        function passwordRequired(rfb) {
            var msg;
            msg = '<form onsubmit="return setPassword();"';
            msg += '  style="margin-bottom: 0px">';
            msg += 'Password Required: ';
            msg += '<input type=password size=10 id="password_input" class="noVNC_status">';
            msg += '<\/form>';
            $D('noVNC_status_bar').setAttribute("class", "noVNC_status_warn");
            $D('noVNC_status').innerHTML = msg;
        }
        function setPassword() {
            rfb.sendPassword($D('password_input').value);
            return false;
        }
        function sendCtrlAltDel() {
            rfb.sendCtrlAltDel();
            return false;
        }
        function disconnect() {
        	rfb.disconnect();
        	return false;
        }
        function updateState(rfb, state, oldstate, msg) {
            var s, sb, cad,dcb, level;
            s = $D('noVNC_status');
            sb = $D('noVNC_status_bar');
            cad = $D('sendCtrlAltDelButton');
            dcb = $D('disconnectButton');
            switch (state) {
                case 'failed':       level = "error";  break;
                case 'fatal':        level = "error";  break;
                case 'normal':       level = "normal"; break;
                case 'disconnected': level = "normal"; break;
                case 'loaded':       level = "normal"; break;
                default:             level = "warn";   break;
            }

            if (state === "normal") { cad.disabled = false;}
            else                    { cad.disabled = true; }
            
            if (state != "disconnected") {dcb.disabled=false;}
            else                         {dcb.disabled=true;}

            if (typeof(msg) !== 'undefined') {
                sb.setAttribute("class", "noVNC_status_" + level);
                s.innerHTML = msg;
            }
        }

        window.onscriptsload = function () {
            var host, port, password, path, token, vmachineid, sessionid;

            $D('sendCtrlAltDelButton').style.display = "inline";
            $D('sendCtrlAltDelButton').onclick = sendCtrlAltDel;
            
            $D('disconnectButton').style.display = "inline";
            $D('disconnectButton').onclick = disconnect;

            WebUtil.init_logging(WebUtil.getQueryVar('logging', 'warn'));
            document.title = unescape(WebUtil.getQueryVar('title', 'noVNC'));
            // By default, use the host and port of server that served this file
            host = WebUtil.getQueryVar('host', window.location.hostname);
            port = WebUtil.getQueryVar('port', window.location.port);

            vmachineid = <%= request.getParameter("vmachineid") %>;
            sessionid = WebUtil.getQueryVar('sessionid');
            
            // If a token variable is passed in, set the parameter in a cookie.
            // This is used by nova-novncproxy.
            token = WebUtil.getQueryVar('token', null);
            if (token) {
                WebUtil.createCookie('token', token, 1)
            }

            //password = WebUtil.getQueryVar('password', '');
            path = WebUtil.getQueryVar('path', 'ovm/rasproxy/proxy');

            if ((!host) || (!port)) {
                updateState('failed',
                    "Must specify host and port in URL");
                return;
            }

            rfb = new RFB({'target':       $D('noVNC_canvas'),
                           'encrypt':      WebUtil.getQueryVar('encrypt',
                                    (window.location.protocol === "https:")),
                           'repeaterID':   WebUtil.getQueryVar('repeaterID', ''),
                           'true_color':   WebUtil.getQueryVar('true_color', true),
                           'local_cursor': WebUtil.getQueryVar('cursor', true),
                           'shared':       WebUtil.getQueryVar('shared', true),
                           'view_only':    WebUtil.getQueryVar('view_only', false),
                           'updateState':  updateState,
                           'onPasswordRequired':  passwordRequired});
            
            
            rfb.connect(host, port, password, path,vmachineid,sessionid);
        };
        </script>

    </body>
</html>

